@@ -1,7 +1,6 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2018, Anaconda, Inc. All rights reserved.
-#
-# Powered by the Bokeh Development Team.
+# Copyright (c) 2012 - 2019, Anaconda, Inc., and Bokeh Contributors.
+# All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
 #-----------------------------------------------------------------------------
@@ -22,8 +21,10 @@ log = logging.getLogger(__name__)
 #-----------------------------------------------------------------------------
 
 # Standard library imports
+import re
 
 # External imports
+from six import string_types
 
 # Bokeh imports
 from ... import colors
@@ -35,7 +36,6 @@ from .either import Either
 from .numeric import Byte, Percent
 from .regex import Regex
 
-
 #-----------------------------------------------------------------------------
 # Globals and constants
 #-----------------------------------------------------------------------------
@@ -43,12 +43,14 @@ from .regex import Regex
 __all__ = (
     'Color',
     'RGB',
+    'ColorHex',
 )
 
 #-----------------------------------------------------------------------------
 # General API
 #-----------------------------------------------------------------------------
 
+
 class RGB(Property):
     ''' Accept colors.RGB values.
 
@@ -61,6 +63,7 @@ class RGB(Property):
             msg = "" if not detail else "expected RGB value, got %r" % (value,)
             raise ValueError(msg)
 
+
 class Color(Either):
     ''' Accept color values in a variety of ways.
 
@@ -99,12 +102,12 @@ class Color(Either):
 
     def __init__(self, default=None, help=None):
         types = (Enum(enums.NamedColor),
-                 Regex("^#[0-9a-fA-F]{6}$"),
-                 Regex("^rgba\(((25[0-5]|2[0-4]\d|1\d{1,2}|\d\d?)\s*,"
-                       "\s*?){2}(25[0-5]|2[0-4]\d|1\d{1,2}|\d\d?)\s*,"
-                       "\s*([01]\.?\d*?)\)"),
-                 Regex("^rgb\(((25[0-5]|2[0-4]\d|1\d{1,2}|\d\d?)\s*,"
-                       "\s*?){2}(25[0-5]|2[0-4]\d|1\d{1,2}|\d\d?)\s*?\)"),
+                 Regex(r"^#[0-9a-fA-F]{6}$"),
+                 Regex(r"^rgba\(((25[0-5]|2[0-4]\d|1\d{1,2}|\d\d?)\s*,"
+                       r"\s*?){2}(25[0-5]|2[0-4]\d|1\d{1,2}|\d\d?)\s*,"
+                       r"\s*([01]\.?\d*?)\)"),
+                 Regex(r"^rgb\(((25[0-5]|2[0-4]\d|1\d{1,2}|\d\d?)\s*,"
+                       r"\s*?){2}(25[0-5]|2[0-4]\d|1\d{1,2}|\d\d?)\s*?\)"),
                  Tuple(Byte, Byte, Byte),
                  Tuple(Byte, Byte, Byte, Percent),
                  RGB)
@@ -121,6 +124,28 @@ class Color(Either):
     def _sphinx_type(self):
         return self._sphinx_prop_link()
 
+
+class ColorHex(Color):
+    ''' ref Color
+
+    The only difference with Color is it's transform in hexadecimal string
+    when send to javascript side
+
+    '''
+
+    def transform(self, value):
+        if isinstance(value, string_types):
+            value = value.lower()
+            if value.startswith('rgb'):
+                value = colors.RGB(*[int(val) for val in re.findall(r"\d+", value)[:3]]).to_hex()
+            elif value in enums.NamedColor:
+                value = getattr(colors.named, value).to_hex()
+        elif isinstance(value, tuple):
+            value = colors.RGB(*value).to_hex()
+        else:
+            value = value.to_hex()
+        return value.lower()
+
 #-----------------------------------------------------------------------------
 # Dev API
 #-----------------------------------------------------------------------------
